*Figure 7

set matsize 11000

	cap: program drop sig
	program sig, rclass
	syntax , coef(real) se(real)
				local p=2 * (1-normal(abs(`coef'/`se')))
				if `p'<=0.01{
					return local sig "^{***}"
				}
				if `p'>0.01 & `p'<=0.05{
					return local sig "^{**}"
				}
				if `p'>0.05 & `p'<=0.1{
					return local sig "^{*}"
				}
				if `p'>0.1{
					return local sig ""
				}
	end

use "$Aux/Main_Data.dta", clear

keep if r>-3000 & r<3000

gen ingr_pc_2=ingr_pc*ingr_pc
gen ingr_pc_3=ingr_pc*ingr_pc*ingr_pc
gen educ_mother_y_s2b_2=educ_mother_y_s2b*educ_mother_y_s2b
gen educ_mother_y_s2b_3=educ_mother_y_s2b*educ_mother_y_s2b*educ_mother_y_s2b
gen educ_father_y_s2b_2=educ_father_y_s2b*educ_father_y_s2b
gen educ_father_y_s2b_3=educ_father_y_s2b*educ_father_y_s2b*educ_father_y_s2b
gen income_s2b_2=income_s2b*income_s2b
gen income_s2b_3=income_s2b*income_s2b*income_s2b

/* Check common support on covariates */
keep if ingr_pc<=433333

mat results = J(1, 4, .)

replace ingr_pc=. if ingr_pc==0

foreach x of varlist ingr_pc educ_mother_y_s2b educ_father_y_s2b income_s2b internet_s2b computer_s2b {
su `x' if r<=0
mat row = (r(min), r(max))
su `x' if r>0
mat row = (row, r(min), r(max))
mat rownames row = "`x'"
mat results = (results\ row)
}

mat results = results[2..., 1...]
mat colnames results = "min_0" "max_0" "min_1" "max_1"
mat list results

egen temp = rowmiss(ingr_pc educ_mother_y_s2b educ_father_y_s2b income_s2b internet_s2b computer_s2b cod_com_alu)
keep if temp == 0
drop temp

global X ingr_pc ingr_pc_2 ingr_pc_3 educ_mother_y_s2b educ_mother_y_s2b_2 educ_mother_y_s2b_3 ///
educ_father_y_s2b educ_father_y_s2b_2 educ_father_y_s2b_3 income_s2b income_s2b_2 income_s2b_3 internet_s2b computer_s2b ///
i.cod_com_alu


foreach method in kline {
	local i=0
	if ("`method'" == "kline") {
	local m="k"
	}
	if ("`method'" == "hir") {
	local m="h"
	}
	
	foreach outcome of varlist  private simce_4b_11_st  educ_4b_11_st copago_us class_size distance lect_s2b_st lect_s4b_st mat_s4b_st{
	local i=`i'+1

	preserve
	qui:ciest $X, outcome(`outcome') method(`method')
	local est0_`i'_`m' = `r(effect0)'
	local est1_`i'_`m' = `r(effect1)'
	local n0_`i'_`m' = `r(n0)'
	local n1_`i'_`m' = `r(n1)'
						
		*Graph
		
		if ("`method'" == "kline") {
			
			lpoly pred0 r, degree(1) kernel(triangle) generate(fit0) at(r) nograph
			lpoly pred1 r, degree(1) kernel(triangle) generate(fit1) at(r) nograph
								
			egen temp_x = cut(r), at(-5000(250)10000)
			replace temp_x = temp_x  + (1/2)
			bysort temp_x: egen temp_y = mean(`outcome')
			bysort temp_x: egen temp_fit0 = mean(fit0)
			bysort temp_x: egen temp_fit1 = mean(fit1)
			bysort temp_x: egen temp_pred0 = mean(pred0)
			bysort temp_x: egen temp_pred1 = mean(pred1)
			bysort temp_x: gen temp_i = _n

			if ("`outcome'" == "private") {
				local title = "Private School"
			}
			else if ("`outcome'" == "simce_4b_11_st") {
				local title = "School's Test Scores"
			}
			else if ("`outcome'" == "educ_4b_11_st") {
				local title = "School's SES"
			}
			else if ("`outcome'" == "copago_us") {
				local title = "School's Monthly Add-On"
			}
			else if ("`outcome'" == "size") {
				local title = "School's Size"
			}
			else if ("`outcome'" == "class_size") {
				local title = "School's Class Size"
			}
			else if ("`outcome'" == "distance") {
				local title = "Distance to School"
			}
			else if ("`outcome'" == "lect_s2b_st") {
				local title = "Student's Language Test Scores 2nd"
			}
			else if ("`outcome'" == "lect_s4b_st") {
			local title = "Student's Language Test Scores 4th"
			}
			else if ("`outcome'" == "mat_s4b_st") {
			local title = "Student's Math Test Scores 4th"
			}
							

			graph twoway (scatter temp_y temp_x if  r <= 0 & temp_i == 1,  mcolor(black) ) ///
			(scatter temp_y temp_x if  r > 0 & temp_i == 1,  mcolor(gs10) ) ///
			(scatter temp_pred0 temp_x if  r <= 0 & temp_i == 1, msymbol(T) mcolor(gs10)) ///
			(scatter temp_pred1 temp_x if  r > 0 & temp_i == 1, msymbol(T) mcolor(black)) ///
			(lpoly fit0 r if  r > 0, degree(1) kernel(triangle) lcolor(gs10) lpattern(solid) lwidth(medthick)) ///
			(lpoly fit0 r if  r <= 0, degree(1) kernel(triangle) lpattern(dash) lwidth(medthick) lcolor(gs10)) ///
			(lpoly fit1 r if  r <= 0, degree(1) kernel(triangle) lcolor(black) lpattern(solid) lwidth(medthick)) ///
			(lpoly fit1 r if  r > 0, degree(1) kernel(triangle) lpattern(dash) lwidth(medthick) lcolor(black)) ///
			, legend(order(5 6 7 8) size(small) label(5 "Control Fitted") label(6 "Control Extrapolated") label(7 "Treated Fitted") label(8 "Treated Extrapolated") ) xtitle("Standardized Running Variable") ytitle("`title'") ///
			xline(0, lcolor(black))  graphregion(color(white) fcolor(white)) plotregion(color(white) fcolor(white)) plotregion(style(none))

			graph save Graph "$Figures/fit_`outcome'.gph", replace
			graph export "$Figures/fit_`outcome'.pdf", replace
		
		drop pred0 pred1 effect
		}
	restore

	}
}
