*Figure A4

use "$Aux/Main_Data.dta", clear

keep if r>-3000 & r<3000

gen ingr_pc_2=ingr_pc*ingr_pc
gen ingr_pc_3=ingr_pc*ingr_pc*ingr_pc
gen educ_mother_y_s2b_2=educ_mother_y_s2b*educ_mother_y_s2b
gen educ_mother_y_s2b_3=educ_mother_y_s2b*educ_mother_y_s2b*educ_mother_y_s2b
gen educ_father_y_s2b_2=educ_father_y_s2b*educ_father_y_s2b
gen educ_father_y_s2b_3=educ_father_y_s2b*educ_father_y_s2b*educ_father_y_s2b
gen income_s2b_2=income_s2b*income_s2b
gen income_s2b_3=income_s2b*income_s2b*income_s2b

/* Check common support on covariates */
keep if ingr_pc<=433333

mat results = J(1, 4, .)

replace ingr_pc=. if ingr_pc==0

foreach x of varlist ingr_pc educ_mother_y_s2b educ_father_y_s2b income_s2b internet_s2b computer_s2b {
su `x' if r<=0
mat row = (r(min), r(max))
su `x' if r>0
mat row = (row, r(min), r(max))
mat rownames row = "`x'"
mat results = (results\ row)
}

mat results = results[2..., 1...]
mat colnames results = "min_0" "max_0" "min_1" "max_1"
mat list results

egen temp = rowmiss(ingr_pc educ_mother_y_s2b educ_father_y_s2b income_s2b internet_s2b computer_s2b cod_com_alu)
keep if temp == 0
drop temp

global X ingr_pc ingr_pc_2 ingr_pc_3 educ_mother_y_s2b educ_mother_y_s2b_2 educ_mother_y_s2b_3 ///
educ_father_y_s2b educ_father_y_s2b_2 educ_father_y_s2b_3 income_s2b income_s2b_2 income_s2b_3 internet_s2b computer_s2b ///
i.cod_com_alu


foreach var of varlist private simce_4b_11_st  educ_4b_11_st copago_us size class_size distance lect_s2b_st lect_s4b_st mat_s4b_st{
preserve
	xi: reg `var' $X i.cod_com_alu if treat == 1, r
	predict res_y0, res	

	xi: reg `var' $X i.cod_com_alu if treat == 0, r
	predict res_y1, res	

	gen res_y = (1 - treat)*res_y1 + treat*res_y0

	rdob_mod2 res_y r, c(0) dm(1)
	local h_opt = r(h_opt)
	gen lambda = (1 - abs(r/`h_opt'))*(abs(r/`h_opt') <= 1)

	lpoly res_y r if r<=0, kernel(triangle) bw(`h_opt') degree(1) gen(pred0) at(r) nograph
	lpoly res_y r if r>0 , kernel(triangle) bw(`h_opt') degree(1) gen(pred1) at(r) nograph
	gen pred = pred0 if r<=0
	replace pred = pred1 if r>0

	egen temp_x = cut(r), at(-3000(125)3000)
	replace temp_x = temp_x  + (1/2)
	bysort temp_x: egen temp_y = mean(res_y)
	bysort temp_x: gen temp_i = _n	

	else if ("`var'" == "private") {
	local title = "Private School (Residual)"
	local ymin=-0.2
	local ymax=0.2
	local yr=0.1
	}
	else if ("`var'" == "simce_4b_11_st") {
	local title = "School's Standardized Test Scores (Residual)"
	local ymin=-0.2
	local ymax=0.2
	local yr=0.1
	}
	else if ("`var'" == "educ_4b_11_st") {
	local title = "School's SES (Residual)"
	local ymin=-0.2
	local ymax=0.2
	local yr=0.1
	}
	else if ("`var'" == "copago_us") {
	local title = "School's Monthly Add-on in US Dollars (Residual)"
	local ymin=-20
	local ymax=20
	local yr=10
	}
	else if ("`var'" == "size") {
	local title = "School's Size (Residual)"
	local ymin=-20
	local ymax=20
	local yr=10
	}
	else if ("`var'" == "class_size") {
	local title = "Schools Class Size (Residual)"
	local ymin=-4
	local ymax=4
	local yr=2
	}
	else if ("`var'" == "distance") {
	local title = "Distance to School (Residual)"
	local ymin=-0.5
	local ymax=0.5
	local yr=0.25
	}
	else if ("`var'" == "lect_s2b_st") {
	local title = "Student's Lang. TS 2nd Grade (Residual)"
	local ymin=-0.2
	local ymax=0.2
	local yr=0.1
	}
	else if ("`var'" == "lect_s4b_st") {
	local title = "Student's Lang. TS 4th Grade (Residual)"
	local ymin=-0.2
	local ymax=0.2
	local yr=0.1
	}
	else if ("`var'" == "mat_s4b_st") {
	local title = "Student's Math TS 4th Grade (Residual)"
	local ymin=-0.2
	local ymax=0.2
	local yr=0.1
	}
	
			
graph twoway (scatter temp_y temp_x if  temp_i == 1,  mcolor(gs10) ) ///
(line pred r if r<=0, lcolor(black) lpattern(solid) lwidth(medthick) sort) ///
(line pred r if r>0, lcolor(black) lpattern(solid) lwidth(medthick) sort) ///
(pci  0 -3000 0 3000, lcolor(gs10) lpattern(dash)), ///
legend(off) xtitle("Standardized Running Variable") ytitle("`title'") ///
xline(0, lcolor(black))  graphregion(color(white) fcolor(white)) plotregion(color(white) ///
fcolor(white)) plotregion(style(none)) yscale(range(`ymin' `ymax' )) ylabel(`ymin' (`yr') `ymax') xscale(range(-3000 3000 )) xlabel(-3000 (1500) 3000)

graph save Graph "$Figures/res_`var'.gph", replace
graph export "$Figures/res_`var'.png", replace
restore
}	
