*Figure A5

use "$Aux/Main_Data.dta", clear

keep if r>-3000 & r<3000

gen ingr_pc_2=ingr_pc*ingr_pc
gen ingr_pc_3=ingr_pc*ingr_pc*ingr_pc
gen educ_mother_y_s2b_2=educ_mother_y_s2b*educ_mother_y_s2b
gen educ_mother_y_s2b_3=educ_mother_y_s2b*educ_mother_y_s2b*educ_mother_y_s2b
gen educ_father_y_s2b_2=educ_father_y_s2b*educ_father_y_s2b
gen educ_father_y_s2b_3=educ_father_y_s2b*educ_father_y_s2b*educ_father_y_s2b
gen income_s2b_2=income_s2b*income_s2b
gen income_s2b_3=income_s2b*income_s2b*income_s2b

/* Check common support on covariates */
keep if ingr_pc<=433333

mat results = J(1, 4, .)

replace ingr_pc=. if ingr_pc==0

foreach x of varlist ingr_pc educ_mother_y_s2b educ_father_y_s2b income_s2b internet_s2b computer_s2b {
su `x' if r<=0
mat row = (r(min), r(max))
su `x' if r>0
mat row = (row, r(min), r(max))
mat rownames row = "`x'"
mat results = (results\ row)
}

mat results = results[2..., 1...]
mat colnames results = "min_0" "max_0" "min_1" "max_1"
mat list results

egen temp = rowmiss(ingr_pc educ_mother_y_s2b educ_father_y_s2b income_s2b internet_s2b computer_s2b cod_com_alu)
keep if temp == 0
drop temp

global X ingr_pc ingr_pc_2 ingr_pc_3 educ_mother_y_s2b educ_mother_y_s2b_2 educ_mother_y_s2b_3 ///
educ_father_y_s2b educ_father_y_s2b_2 educ_father_y_s2b_3 income_s2b income_s2b_2 income_s2b_3 internet_s2b computer_s2b ///
i.cod_com_alu

/* Check common support on pscore */

xi: logit treat $X i.cod_com_alu
local n = e(N)
predict pred
egen temp = cut(pred), at(0(0.1)1)
egen temp_x = group(temp)
replace temp_x = temp_x - 0.5
drop temp

bysort temp_x: egen temp = count(temp_x) if treat == 0
bysort temp_x: egen temp_y0 = mean(temp)
drop temp				

count if temp_x != . & treat == 0
replace temp_y0 = -temp_y0
su temp_y0

			
bysort temp_x: egen temp = count(temp_x) if treat== 1
bysort temp_x: egen temp_y1 = mean(temp)
drop temp
count if temp_x != . & treat== 1
replace temp_y1 = temp_y1
				
bysort temp_x: gen temp_i = _n

graph twoway (bar temp_y1 temp_x if temp_i == 1, bcolor(black)) ///
(bar temp_y0 temp_x if temp_i == 1, bcolor(gs10) ///
 xtitle("Propensity Score") ytitle("Frequency") legend(label(1 "Treated") label(2 "Untreated") size(small)) ///
xlabel(0 "0" 2 "0.2" 4 "0.4" 6 "0.6" 8 "0.8" 10 "1") graphregion(color(white) fcolor(white)) ///
plotregion(color(white) fcolor(white)) plotregion(style(none)) )


graph save Graph "$Figures/p_score.gph", replace
graph export "$Figures/p_score.png", replace
